package com.persagy.server.controllers.rel

import com.persagy.base.extensions.toJson
import com.persagy.server.datacenter.models.entities.rel.RBdForEqList
import com.persagy.server.datacenter.models.entities.rel.REq2Bd
import com.persagy.server.datacenter.models.entities.rel.REqForBdList
import com.persagy.server.services.rel.REqForBdService
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 设备服务于建筑
 *
 * @author 付国宝
 */
@Api(tags = ["036、关系-设备服务于建筑"])
@RestController
@RequestMapping("/rel/eq-for-bd")
class REqForBdController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(REqForBdController::class.java)
    } // Companion object

    /**
     * 创建设备服务于建筑关系
     *
     * @param   req2Bd     设备和建筑的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "创建设备服务于建筑关系", notes = "必填项：EquipId（设备id）、BuildingId（建筑id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody req2Bd: REq2Bd): SCreateResponse<REq2Bd>{
        logger.debug("build = ${req2Bd.toJson()}")
        return REqForBdService.create(req2Bd)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rEqForBd      对象
     * @return                删除的结果信息
     */
    @ApiOperation(value = "根据对象删除设备服务于建筑的关系，只针对一个对象", notes = "必填项：EquipId（设备id）、BuildingId(建筑id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody req2Bd: REq2Bd): SBaseResponse {
        return REqForBdService.deletes(req2Bd)
    } // Function delete()

    /**
     * 创建设备服务于建筑关系
     *
     * @param   rEqForBd    设备和建筑关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "设备服务于建筑，设备一对多", notes = "必填项：BuildingIdList（建筑id列表）、EquipId（设备id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["link-bd"])
    fun createBd(@RequestBody rEqForBd: REqForBdList): SCreateResponse<REq2Bd>{
        logger.debug("build =${rEqForBd.toJson()}")
        return REqForBdService.createEq(rEqForBd)
    } // Function createBd()

    /**
     * 创建服务于建筑的设备关系
     *
     * @param   rEqForBd    设备和建筑关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "服务于建筑的设备，建筑一对多",notes = "必填项：EquipIdList（设备id列表）、BuildingId（建筑id），测方法会覆盖以前的记录")
    @PostMapping(value = ["link-sy"])
    fun createSy(@RequestBody rEqForBd: RBdForEqList): SCreateResponse<REq2Bd>{
        logger.debug("build =${rEqForBd.toJson()}")
        return REqForBdService.createsBd(rEqForBd)
    } // Function createSy()

} // Class RSyForBdController