package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.REqForSpBase
import com.persagy.server.datacenter.models.entities.rel.RSpForEqBaseList
import com.persagy.server.services.rel.REqForSpBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 设备服务于业务空间
 *
 * @author 付国宝
 */
@Api(tags = ["018、关系-设备服务于业务空间"])
@RestController
@RequestMapping("/rel/eq-for-sp-base")
class REqForSpConreoller {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(REqForSpConreoller::class.java)
    } // Companion object

    /**
     * 创建设备服务于业务空间关系
     *
     * @param    rEqForSpBase    设备和业务空间的关系对象
     * @return                   创建的结果信息
     */
    @ApiOperation(value = "创建设备服务于业务空间关系", notes = "必填项：EquipId（设备id）、SpaceId（业务空间id）")
    @PostMapping(value = ["/link-list"])
    fun create(type: String, @RequestBody rEqForSpBase: SCreateRequest<REqForSpBase>): SCreateResponse<REqForSpBase> {
        logger.debug("space = ${rEqForSpBase.toJson()}")
        return REqForSpBaseService.create(type,rEqForSpBase)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param    rEqForSpBaseList    对象 列表
     * @return                       删除的结果信息
     */
    @ApiOperation(value = "根据对象删除设备服务于业务空间关系", notes = "必填项：EquipId（设备id）、SpaceId（业务空间id）")
    @PostMapping(value = ["/unlink-list"])
    fun deleteList(type: String, @RequestBody rEqForSpBaseList: ArrayList<REqForSpBase>): SBaseResponse {
        return REqForSpBaseService.deletes(type,rEqForSpBaseList)
    } // Function delete()

    /**
     * 创建服务于业务空间的设备关系
     *
     * @param    rEqForSpBase     设备和业务空间的关系对象
     * @return                    创建的结果信息
     */
    @ApiOperation(value = "服务于业务空间的设备，业务空间一对多,累计添加不会覆盖以前记录", notes = "必填项：EquipIdList（设备id列表）、SpaceId（业务空间id)")
    @PostMapping(value = ["/link-eq-sp"])
    fun createEqSp(type: String,@RequestBody rEqForSpBase: RSpForEqBaseList): SCreateResponse<RSpForEqBaseList>{
        logger.debug("space = ${rEqForSpBase.toJson()}")
        return REqForSpBaseService.createsSpEq(type,rEqForSpBase)
    } // Function createEq()

} // Class REqForSpBaseConreoller