package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RSiInSpBase
import com.persagy.server.datacenter.models.entities.rel.RSiInSpBaseList
import com.persagy.server.services.rel.RSpInSiBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController


/**
 * 业务空间内的元空间
 *
 * @author 付国宝
 */
@Api(tags = ["035、关系-业务空间内的模型空间"])
@RestController
@RequestMapping("/rel/si-in-sp-base")
class RSpInSiController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSpInSiController::class.java)
    } // Companion object

    /**
     * 创建业务空间内的元空间关系
     *
     * @param     rSiInSpBase    元空间内的业务空间关系对象
     * @return                   创建的结果信息
     */
    @ApiOperation(value = "创建业务空间内的元空间关系, 累计添加不会覆盖", notes = "必填项：IspaceId（元空间id）、SpaceId（业务空间id）")
    @PostMapping(value = ["/link-list"])
    fun create(type: String, @RequestBody rSiInSpBase: SCreateRequest<RSiInSpBase>): SCreateResponse<RSiInSpBase> {
        logger.debug("space = ${rSiInSpBase.toJson()}")
        return RSpInSiBaseService.createLists(type,rSiInSpBase)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param    rSiInSpBase    对象
     * @return                  删除的结果信息
     */
    @ApiOperation(value = "根据对象删除业务空间内的元空间关系", notes = "必填项：IspaceId（元空间id）、SpaceId（业务空间id）")
    @PostMapping(value = ["/unlink"])
    fun delete(type: String, @RequestBody rSiInSpBase: ArrayList<RSiInSpBase>): SBaseResponse {
        return RSpInSiBaseService.deletes(type,rSiInSpBase)
    } // Function delete()

//    /**
//     * 创建业务空间内的元空间关系
//     *
//     * @param    rSpInSiBase    业务空间和元空间的关系对象
//     * @return                  创建的结果信息
//     */
//    @ApiOperation(value = "元空间关联业务空间，元空间一对多", notes = "必填项：IspaceId（元空间id）、SpaceIdList（业务空间id列表）,测方法会覆盖以前的记录")
//    @PostMapping(value = ["/link-si"])
//    fun createSi(@RequestBody rSpInSiBase: RSpInSiBaseList): SCreateResponse<RSiInSpBase>{
//        logger.debug("space = ${rSpInSiBase.toJson()}")
//        return RSpInSiBaseService.createSp(rSpInSiBase)
//    } // Function createSi()

    /**
     * 创建业务空间内的元空间关系
     *
     * @param    rSpInSiBase    业务空间和元空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "业务空间内的元空间，业务空间一对多，此方法会覆盖以前的记录", notes = "必填项：IspaceIdList（元空间id列表）、SpaceId（业务空间id），此方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sp"])
    fun createSp(type:String, @RequestBody rSpInSiBase: RSiInSpBaseList): SCreateResponse<RSiInSpBaseList>{
        logger.debug("space = ${rSpInSiBase.toJson()}")
        return RSpInSiBaseService.createsSp(type,rSpInSiBase)
    } // Function createSp()

    /**
     * 创建业务空间内的元空间关系
     *
     * @param    rSpInSiBase    业务空间和元空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "业务空间内的元空间，业务空间一对多,累计添加不会覆盖以前记录", notes = "必填项：IspaceIdList（元空间id列表）、SpaceId（业务空间id）")
    @PostMapping(value = ["/link-si-sp"])
    fun createSpSi(type:String, @RequestBody rSpInSiBase: RSiInSpBaseList): SCreateResponse<RSiInSpBaseList>{
        logger.debug("space = ${rSpInSiBase.toJson()}")
        return RSpInSiBaseService.createsSpSi(type, rSpInSiBase)
    } // Function createSp()

} // Class RSpInSiBaseController