package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RFlForSyList
import com.persagy.server.datacenter.models.entities.rel.RSyForFl
import com.persagy.server.datacenter.models.entities.rel.RSyForFlList
import com.persagy.server.services.rel.RSyForFlService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统服务于楼层
 *
 * @author 付国宝
 */
@Api(tags = ["027、关系-系统服务于楼层"])
@RestController
@RequestMapping("/rel/sy-for-fl")
class RSyForFlController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyForFlController::class.java)
    } // Companion object

    /**
     * 创建系统服务于楼层关系
     *
     * @param   rSyForFl    系统和楼层的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "创建系统服务于楼层关系", notes = "必填项：SysId（系统id）、FloorId（楼层id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyForFl: RSyForFl): SCreateResponse<RSyForFl>{
        logger.debug("floor = ${rSyForFl.toJson()}")
        return RSyForFlService.create(rSyForFl)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyForFl    对象
     * @return              删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统服务于楼层的关系，只针对一个对象", notes = "必填项：SysId（系统id）、FloorId（楼层id）")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyForFl: RSyForFl): SBaseResponse{
        return RSyForFlService.deletes(rSyForFl)
    } // Function delete()

    /**
     * 创建系统服务于楼层关系
     *
     * @param    rSyForFl    系统和楼层关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "系统服务于楼层，系统一对多", notes = "必填项：FloorIdList（楼层id列表）、SysId（系统id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-fl"])
    fun createFl(@RequestBody rSyForFl: RSyForFlList): SCreateResponse<RSyForFl>{
        logger.debug("floor = ${rSyForFl.toJson()}")
        return RSyForFlService.createSy(rSyForFl)
    } // Function createFl()

    /**
     * 创建服务于楼层的系统
     *
     * @param   rSyForFl    系统和楼层关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "服务于楼层的系统，楼层一对多", notes = "必填项：FloorId（楼层id）、sysIdList（系统id列表）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyForFl: RFlForSyList): SCreateResponse<RSyForFl>{
        logger.debug("floor = ${rSyForFl.toJson()}")
        return RSyForFlService.createsFl(rSyForFl)
    } // Function createSy()

} // Class RSyForFlController