package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RShForSyList
import com.persagy.server.datacenter.models.entities.rel.RSyForSh
import com.persagy.server.datacenter.models.entities.rel.RSyForShList
import com.persagy.server.services.rel.RSyForShService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统服务于竖井
 *
 * @author 付国宝
 */
@Api(tags = ["028、关系-系统服务于竖井"])
@RestController
@RequestMapping("/rel/sy-for-sh")
class RSyForShController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyForShController::class.java)
    } // Companion object

    /**
     * 创建系统服务于竖井关系
     *
     * @param    rSyForSh    系统和竖井的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "创建系统服务于竖井关系", notes = "必填项：SysId（系统id）、ShaftId（竖井id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyForSh: RSyForSh): SCreateResponse<RSyForSh>{
        logger.debug("shaft = ${rSyForSh.toJson()}")
        return RSyForShService.create(rSyForSh)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param    rSyForSh    对象
     * @return               删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统服务于竖井的关系，只针对一个对象", notes = "必填项：SysId（系统id）、ShaftId（竖井id）")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyForSh: RSyForSh): SBaseResponse{
        return RSyForShService.deletes(rSyForSh)
    } // Function delete()

    /**
     * 创建系统服务于竖井关系
     *
     * @param   rSyForSh    系统和竖井关系的对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统服务于竖井，系统一对多", notes = "必填项：ShaftIdList（竖井id列表）、SysId（系统id），测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sh"])
    fun createSh(@RequestBody rSyForSh: RSyForShList): SCreateResponse<RSyForSh>{
        logger.debug("shaft = ${rSyForSh.toJson()}")
        return RSyForShService.createSy(rSyForSh)
    } // Function createSh()

    /**
     * 创建服务于竖井的系统关系
     *
     * @param   rSyForSh     系统和竖井关系的对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "服务于竖井的系统，竖井一对多", notes = "必填项：ShaftId（竖井id）、sysIdList（系统id列表），测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyForSh: RShForSyList): SCreateResponse<RSyForSh>{
        logger.debug("shaft = ${rSyForSh.toJson()}")
        return RSyForShService.createsSh(rSyForSh)
    } // Function createSy()

} // Class RSyForShController