package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RSpForSyBaseList
import com.persagy.server.datacenter.models.entities.rel.RSyForSpBase
import com.persagy.server.datacenter.models.entities.rel.RSyForSpBaseList
import com.persagy.server.services.rel.RSyForSpBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统服务于业务空间
 *
 * @author 付国宝
 */
@Api(tags = ["029、关系-系统服务于业务空间"])
@RestController
@RequestMapping("/rel/sy-for-sp-base")
class RSyForSpController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyForSpController::class.java)
    } // Companion object

    /**
     * 创建系统服务于业务空间关系
     *
     * @param    rSyForSpBase       系统和业务空间的关系对象
     * @return                      创建的结果信息
     */
    @ApiOperation(value = "创建系统服务于业务空间关系", notes = "必填项：SysID（系统id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyForSpBase: RSyForSpBase): SCreateResponse<RSyForSpBase> {
        logger.debug("space =${rSyForSpBase.toJson()}")
        return RSyForSpBaseService.create(rSyForSpBase)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyForSpBase      对象
     * @return                    删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统服务于业务空间关系，只针对一个对象", notes = "必填项：SysID（系统id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyForSpBase: RSyForSpBase): SBaseResponse {
        return RSyForSpBaseService.deletes(rSyForSpBase)
    } // Function delete()

    /**
     * 创建系统服务于业务空间关系
     *
     * @param   rSyForSpBase   系统和业务空间的关系对象
     * @return                 创建的结果信息
     */
    @ApiOperation(value = "系统服务于业务空间关系，系统一对多", notes = "必填项：SpaceIdList（业务空间id列表）、SysID(系统id)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sp"])
    fun createSp(@RequestBody rSyForSpBase: RSyForSpBaseList): SCreateResponse<RSyForSpBase> {
        logger.debug("space =${rSyForSpBase.toJson()}")
        return RSyForSpBaseService.createSy(rSyForSpBase)
    } // Function createSp()

    /**
     * 创建服务于业务空间的系统关系
     *
     * @param   rSyForSpBase    系统和业务空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "服务于业务空间的系统，业务空间一对多",notes = "必填项：SpaceId（业务空间id）、SysIDList(系统id列表)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyForSpBase: RSpForSyBaseList): SCreateResponse<RSyForSpBase> {
        logger.debug("space =${rSyForSpBase.toJson()}")
        return RSyForSpBaseService.createsSp(rSyForSpBase)
    } // Function createSy()

} // Class RSyForSpController