package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RBdInSyList
import com.persagy.server.datacenter.models.entities.rel.RSyInBd
import com.persagy.server.datacenter.models.entities.rel.RSyInBdList
import com.persagy.server.services.rel.RSyInBdService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统所在建筑
 *
 * @author 付国宝
 */
@Api(tags = ["030、关系-系统所在建筑"])
@RestController
@RequestMapping("/rel/sy-in-bd")
class RSyInBdController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyInBdController::class.java)
    } // Companion object

    /**
     * 创建系统所在建筑关系
     *
     * @param    rSyInBd     系统和建筑的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "创建系统所在建筑关系", notes = "必填项：SysId（系统id）、BuildingId（建筑id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyInBd: RSyInBd): SCreateResponse<RSyInBd> {
        logger.debug("build = ${rSyInBd.toJson()}")
        return RSyInBdService.create(rSyInBd)
    } //Function create()

    /**
     * 根据对象删除
     *
     * @param    rSyInBd      对象
     * @return                删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统所在建筑关系，只针对一个对象", notes = "必填项：SysId（系统id）、BuildingId（建筑id）")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyInBd: RSyInBd): SBaseResponse {
        return RSyInBdService.deletes(rSyInBd)
    } // Function delete()

    /**
     * 创建系统所在建筑关系
     *
     * @param    rSyInBd     系统和建筑的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "系统所在建筑，系统一对多建筑", notes = "必填项：SysId（系统id）、BuildingIdList（建筑id列表）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-bd"])
    fun createBd(@RequestBody rSyInBd: RSyInBdList): SCreateResponse<RSyInBd>{
        logger.debug("build = ${rSyInBd.toJson()}")
        return RSyInBdService.createSy(rSyInBd)
    } // Function createBd()

    /**
     * 创建所在建筑的系统关系
     *
     * @param    rSyInBd      系统和建筑的关系对象
     * @return                创建的结果信息
     */
    @ApiOperation(value = "所在建筑的系统，建筑一对多系统", notes = "必填项：sysIdList（系统id列表）、BuildingId（建筑id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyInBd: RBdInSyList): SCreateResponse<RSyInBd>{
        logger.debug("build = ${rSyInBd.toJson()}")
        return  RSyInBdService.createsBd(rSyInBd)
    } // Function createSy()

    /**
     * 创建系统所在建筑关系
     *
     * @param    rSyInBd     系统和建筑的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "系统所在建筑，系统一对多建筑,此方法不会覆盖", notes = "必填项：SysId（系统id）、BuildingIdList（建筑id列表）")
    @PostMapping(value = ["/link-bd-sy"])
    fun createSyBd(@RequestBody rSyInBd: RSyInBdList): SCreateResponse<RSyInBd>{
        logger.debug("build = ${rSyInBd.toJson()}")
        return RSyInBdService.createSy(rSyInBd)
    } // Function createBd()

} // Class RSyInBdController