package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RFlInSyList
import com.persagy.server.datacenter.models.entities.rel.RSyInFl
import com.persagy.server.datacenter.models.entities.rel.RSyInFlList
import com.persagy.server.services.rel.RSyInFlService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统所在楼层
 *
 * @author 付国宝
 */
@Api(tags = ["031、关系-系统所在楼层"])
@RestController
@RequestMapping("/rel/sy-in-fl")
class RSyInFlController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyInFlController::class.java)
    } // Companion object

    /**
     * 创建系所在楼层关系
     *
     * @param    rSyInFl    系统和楼层的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "创建系所在楼层关系", notes = "必填项：SysId（系统id）、FloorId（楼层id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyInFl: RSyInFl): SCreateResponse<RSyInFl> {
        logger.debug("floor = ${rSyInFl.toJson()}")
        return RSyInFlService.create(rSyInFl)
    } //Function create()

    /**
     * 根据对象删除
     *
     * @param    rSyInFl     对象
     * @return               删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统所在楼层关系，只针对一个对象", notes = "必填项：SysId（系统id）、FloorId（楼层id）")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyInFl: RSyInFl): SBaseResponse {
        return RSyInFlService.deletes(rSyInFl)
    } // Function delete()

    /**
     * 创建系统所在楼层关系
     *
     * @param    rSyInFl    系统和楼层的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统所在楼层，系统一对多楼层", notes = "必填项：SysId（系统id）、FloorIdList（楼层id列表）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-fl"])
    fun createFl(@RequestBody rSyInFl: RSyInFlList): SCreateResponse<RSyInFl>{
        logger.debug("floor = ${rSyInFl.toJson()}")
        return RSyInFlService.createSy(rSyInFl)
    } // Function createFl()

    /**
     * 创建所在楼层的系统关系
     *
     * @param    rSyInFl    系统和楼层的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "所在楼层的系统，楼层一对多系统", notes = "必填项：sysIdList（系统id列表）、FloorId（楼层id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyInFl: RFlInSyList): SCreateResponse<RSyInFl>{
        logger.debug("floor = ${rSyInFl.toJson()}")
        return  RSyInFlService.createsFl(rSyInFl)
    } // Function createSy()

    /**
     * 创建系统所在楼层关系
     *
     * @param    rSyInFl    系统和楼层的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统所在楼层，系统一对多楼层,此方法不会覆盖", notes = "必填项：SysId（系统id）、FloorIdList（楼层id列表）")
    @PostMapping(value = ["/link-fl-sy"])
    fun createSyFl(@RequestBody rSyInFl: RSyInFlList): SCreateResponse<RSyInFl>{
        logger.debug("floor = ${rSyInFl.toJson()}")
        return RSyInFlService.createSyFl(rSyInFl)
    } // Function createFl()

} // Class RSyInFlController