package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RShInSyList
import com.persagy.server.datacenter.models.entities.rel.RSyInSh
import com.persagy.server.datacenter.models.entities.rel.RSyInShList
import com.persagy.server.services.rel.RSyInShService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统所在竖井
 *
 * @author 付国宝
 */
@Api(tags = ["032、关系-系统所在竖井"])
@RestController
@RequestMapping("/rel/sy-in-sh")
class RSyInShController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyInShController::class.java)
    } // Companion object

    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInSh    系统和竖井的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "创建系统所在竖井关系", notes = "必填项：SysId（系统id）、ShaftId（竖井id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyInSh: RSyInSh): SCreateResponse<RSyInSh> {
        logger.debug("shaft = ${rSyInSh.toJson()}")
        return RSyInShService.create(rSyInSh)
    } //Function create()

    /**
     * 根据对象删除
     *
     * @param     rSyInSh     对象
     * @return                删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统所在竖井关系，只针对一个对象", notes = "必填项：SysId（系统id）、ShaftId（竖井id）")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyInSh: RSyInSh): SBaseResponse {
        return RSyInShService.deletes(rSyInSh)
    } // Function delete()

    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInSh    系统和竖井的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统所在竖井，系统一对多，此方法会覆盖以前的记录", notes = "必填项：SysId（系统id）、ShaftIdList（竖井id列表）,此方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sh"])
    fun createSh(@RequestBody rSyInSh: RSyInShList): SCreateResponse<RSyInSh>{
        logger.debug("shaft = ${rSyInSh.toJson()}")
        return RSyInShService.createSy(rSyInSh)
    } // Function createSh()

    /**
     * 创建所在竖井的系统关系
     *
     * @param     rSyInSh    系统和竖井的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "所在竖井的系统，竖井一对多，此方法会覆盖以前的记录", notes = "必填项：sysIdList（系统id列表）、ShaftId（竖井id）,此方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyInSh: RShInSyList): SCreateResponse<RSyInSh>{
        logger.debug("shaft = ${rSyInSh.toJson()}")
        return  RSyInShService.createsSh(rSyInSh)
    } // Function createSy()

    /**
     * 创建所在竖井的系统关系
     *
     * @param     rSyInSh    系统和竖井的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "系统所在的竖井，竖井一对多，累计添加，此方法不会覆盖以前记录", notes = "必填项：sysIdList（系统id列表）、ShaftId（竖井id）")
    @PostMapping(value = ["/link-sy-sh"])
    fun createSySh(@RequestBody rSyInSh: RShInSyList): SCreateResponse<RSyInSh>{
        logger.debug("shaft = ${rSyInSh.toJson()}")
        return  RSyInShService.createsShSys(rSyInSh)
    } // Function createSy()


    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInSh    系统和竖井的关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统所在竖井，系统一对多，不覆盖", notes = "必填项：SysId（系统id）、ShaftIdList（竖井id列表）,此方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy-shs"])
    fun createSyShs(@RequestBody rSyInSh: RSyInShList): SCreateResponse<RSyInSh>{
        logger.debug("shaft = ${rSyInSh.toJson()}")
        return RSyInShService.createSyShs(rSyInSh)
    } // Function createSyShs()


} // Class RSyInShController