package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RTnInSpBase
import com.persagy.server.datacenter.models.entities.rel.RTnInSpBaseList
import com.persagy.server.services.rel.RTnInSpBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 租户所租用的业务空间
 *
 * @author 付国宝
 */
@Api(tags = ["034、关系-租户所租用的业务空间"])
@RestController
@RequestMapping("/rel/tn-in-sp-base")
class RTnInSpController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RTnInSpController::class.java)
    } // Companion object

    /**
     * 创建租户所租用的业务空间关系
     *
     * @param    rTnInSpBase    租户和业务空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "创建租户所租用的业务空间关系", notes = "必填项：TenantID（租户id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/link"])
    fun create(type: String,@RequestBody rTnInSpBase: SCreateRequest<RTnInSpBase>): SCreateResponse<RTnInSpBase> {
        logger.debug("space =${rTnInSpBase.toJson()}")
        return RTnInSpBaseService.create(type,rTnInSpBase)
    } // Functio create()

    /**
     * 根据对象删除关系
     *
     * @param   rTnInSpBase      对象
     * @return                   删除的结果信息
     */
    @ApiOperation(value = "根据对象删除租户所租用的业务空间关系", notes = "必填项：TenantID（租户id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/unlink"])
    fun delete(type: String,@RequestBody rTnInSpBase: ArrayList<RTnInSpBase>): SBaseResponse {
        return RTnInSpBaseService.deletes(type,rTnInSpBase)
    } // Function delete()

    /**
     * 创建租户所租用的业务空间关系
     *
     * @param    rTnInSpBase    租户和业务空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "租户所租用的业务空间关系，租户一对多", notes = "必填项：SpaceIdList（业务空间id列表）、TenantID(租户id)，此方法会覆盖以前的记录 ,type 空间类型")
    @PostMapping(value = ["/link-sp"])
    fun createSp(type: String,@RequestBody rTnInSpBase: RTnInSpBaseList): SCreateResponse<RTnInSpBase> {
        logger.debug("space =${rTnInSpBase.toJson()}")
        return RTnInSpBaseService.createTn(type,rTnInSpBase)
    } // Function createSp()

    /**
     * 创建所租用的业务空间的租户关系
     *
     * @param    rTnInSpBase    租户和业务空间的关系对象
     * @return                  创建的结果信息
     */
//    @ApiOperation(value = "所租用的业务空间的租户关系，业务空间一对多", notes = "必填项：SpaceId（业务空间id）、TenantIDList(租户id列表)，测方法会覆盖以前的记录")
//    @PostMapping(value = ["/link-tn"])
//    fun createTn(@RequestBody rTnInSpBase: RSpInTnBaseList): SCreateResponse<RTnInSpBase> {
//        logger.debug("space =${rTnInSpBase.toJson()}")
//        return RTnInSpBaseService.createsSp(rTnInSpBase)
//    } // Function createTn()

} // Class RTnInSpBaseController