package com.persagy.server.services.objects

import com.persagy.server.services.base.RService
import cn.sagacloud.server.datacenter.utils.IdUtils
import cn.sagacloud.server.scanbuilding.User
import com.persagy.server.scanbuilding.UserLog
import com.persagy.server.datacenter.models.entities.assistant.PointImage
import com.persagy.server.datacenter.models.entities.objects.LocationPoint
import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import org.slf4j.LoggerFactory

/**
 * 点位标签服务
 *
 * @author 张维新
 */
object LocationPointServices : RService<LocationPoint>(SMybatisDao(LocationPoint::class.java)) {

    /** 日志 */
    private val logger = LoggerFactory.getLogger(LocationPointServices::class.java)
    /** 点位图片库 */
    var pointImageService = SObjectService(SMybatisDao(PointImage::class.java))
    /** 扫楼日志 */
    var userLogService = SObjectService(SMybatisDao(UserLog::class.java))
    /** 用户 */
    var userService = SObjectService(SMybatisDao(User::class.java))

    /**
     * 创建之前的操作
     */
    override fun onCreateBefore(entity: LocationPoint): Boolean {
        logger.debug("创建的点位=${entity.toJson()}")
        val projectId = SPageContext.getHeader("ProjectId")
        if (entity.id.isNullOrEmpty()) {
            return false
        }
        if (entity.imageList != null && entity.imageList!!.isNotEmpty()) {
            for (image in entity.imageList!!) {
                try {
                    image.objectId = entity.id
                    val replace = pointImageService.replace(image)
                    if (replace){
                        logger.debug("点位图片存储成功*****************************")
                    }else{
                        logger.debug("点位图片存储失败*****************************")
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }
        entity.projectId = projectId
        return super.onCreateBefore(entity)
    } // Function onCreateBefore()

    override fun onCreateSuccess(entityList: ArrayList<LocationPoint>) {
        super.onCreateSuccess(entityList)

        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            for (entity in entityList){
                try {
                    if (!comming.isNullOrEmpty()){
                        if (comming == "app"){
                            val user = userService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("phone", account!!)).entity()
                            val userLog = UserLog()
                            userLog.comming = "app"
                            userLog.action = "创建点位标签"
                            userLog.id = IdUtils.uuidCreate()
                            userLog.note = "项目ID: "+projectId+" 用户ID："+user!!.id+" 手机号："+ account+" 请求来源："+comming+ " "+entity.toJson()
                            userLog.phone = account
                            userLog.projectId = projectId
                            userLog.userId = user!!.id
                            userLog.name = user.name
                            userLog.objectId = entity.id
                            userLogService.insert(userLog)
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }

    } // Fun

    /**
     * 更新之前的操作
     */
    override fun onUpdateBefore(entity: LocationPoint): Boolean {
        if (entity.id.isNullOrEmpty()) {
            return false
        }
        if (entity.imageList != null && entity.imageList!!.isNotEmpty()) {
            for (image in entity.imageList!!) {
                try {
                    image.objectId = entity.id
                    val replace = pointImageService.replace(image)
                    if (replace){

                    }else{

                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }
        return super.onUpdateBefore(entity)
    } // Function onCreateBefore()

    override fun onUpdateSuccess(entityList: ArrayList<LocationPoint>) {
        super.onUpdateSuccess(entityList)
        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            for (entity in entityList){
                try {
                    if (!comming.isNullOrEmpty()){
                        if (comming == "app"){
                            val user = userService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("phone", account!!)).entity()
                            val userLog = UserLog()
                            userLog.comming = "app"
                            userLog.action = "更新点位标签"
                            userLog.id = IdUtils.uuidCreate()
                            userLog.note = "项目ID: "+projectId+" 用户ID："+user!!.id+" 手机号："+ account+" 请求来源："+comming+ " "+entity.toJson()
                            userLog.phone = account
                            userLog.projectId = projectId
                            userLog.userId = user!!.id
                            userLog.name = user.name
                            userLog.objectId = entity.id
                            userLogService.insert(userLog)
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

} // Object LocationPointServices