/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.services.objects

import cn.sagacloud.server.datacenter.utils.IdUtils
import cn.sagacloud.server.datacenter.utils.ShaftNameUtil
import cn.sagacloud.server.scanbuilding.User
import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.database.SQueryBuilder
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.logs.DataCenterLogs
import com.persagy.server.datacenter.models.entities.objects.Equipment
import com.persagy.server.datacenter.models.entities.objects.Property
import com.persagy.server.scanbuilding.UserLog
import com.persagy.server.services.base.Service
import com.persagy.server.services.dict.EquipFamilyService
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext

/**
 * 资产信息服务
 *
 * @author 张维新
 */
object PropertyService : Service<Property>(SMybatisDao(Property::class.java)) {

    /** 扫楼日志 */
    var userLogService = SObjectService(SMybatisDao(UserLog::class.java))
    /** 用户 */
    var userService = SObjectService(SMybatisDao(User::class.java))

    /**
     * 创建之前操作
     */
    override fun onCreateBefore(property: Property): Boolean  {
        val projectId = SPageContext.getHeader("ProjectId")
        val coming = SPageContext.getHeader("Coming")
        if (!property.id.isNullOrEmpty()) {
            val isStartsWith = property.id.toString().startsWith("Pe")
            if (!isStartsWith) {
                /** 资产id */
                property.id = IdUtils.peIdCreate(projectId!!)
            }
        } else {
            /** 资产id */
            property.id = IdUtils.peIdCreate(projectId!!)
        }
        /** 项目id */
        property.projectId = projectId
        // 创建标记
        if(coming.isNullOrEmpty()&&coming == "app"){
            property.source = "app"
        }
        if (!property.family.isNullOrEmpty()){
            val family = EquipFamilyService.select(SFilter.eq("family", property.family!!)).entity()
            if (family!=null){
                /** 资产名字 */
                if (property.name.isNullOrEmpty()) {
                    property.name = ShaftNameUtil.shaftName(family.familyName+"-")
                }
            }else{
                /** 资产名字 */
                if (property.name.isNullOrEmpty()) {
                    property.name = ShaftNameUtil.shaftName("资产-")
                }
            }
            return true
        }else{
            return false
        }
    } // Function onCreateBefore()

    override fun onCreateSuccess(entityList: ArrayList<Property>) {
        super.onCreateSuccess(entityList)
        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            for (entity in entityList){
                try {
                    if (!comming.isNullOrEmpty()){
                        if (comming == "app"){
                            val user = userService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("phone", account!!)).entity()
                            val userLog = UserLog()
                            userLog.comming = "app"
                            userLog.action = "创建资产"
                            userLog.id = IdUtils.uuidCreate()
                            userLog.note = "项目ID: "+projectId+" 用户ID："+user!!.id+" 手机号："+ account+" 请求来源："+comming+ " "+entity.toJson()
                            userLog.phone = account
                            userLog.projectId = projectId
                            userLog.userId = user!!.id
                            userLog.name = user.name
                            userLog.objectId = entity.id
                            userLogService.insert(userLog)
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }



    /**
     * 查询资产数量前的操作
     *
     * @param   queryBuilder  条件
     */
    override fun onCountBefore(queryBuilder: SQueryBuilder<Property>) {
        queryBuilder.tableName = "v_property"
        return
    } // Function onCountBefore()

    /**
     * 查询资产数量前的操作
     *
     * @param   queryBuilder  条件
     */
    override fun onQueryBefore(queryBuilder: SQueryBuilder<Property>) {
        queryBuilder.tableName = "v_property"
        return
    } // Function onQueryBefore()


    override fun onUpdateBefore(entity: Property): Boolean {

        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
                try {
                    if (!comming.isNullOrEmpty()){
                        if (comming == "app"){
                            val user = userService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("phone", account!!)).entity()
                            val userLog = UserLog()
                            userLog.comming = "app"
                            userLog.action = "创建资产"
                            userLog.id = IdUtils.uuidCreate()
                            userLog.note = "项目ID: "+projectId+" 用户ID："+user!!.id+" 手机号："+ account+" 请求来源："+comming+ " "+entity.toJson()
                            userLog.phone = account
                            userLog.projectId = projectId
                            userLog.userId = user!!.id
                            userLog.name = user.name
                            userLog.objectId = entity.id
                            userLogService.insert(userLog)
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }

        } catch (e: Exception) {
            e.printStackTrace()
        }
        return super.onUpdateBefore(entity)
    }



    /**
     * 删除之前操作
     */
    override fun onDeleteBefore(entity: Property): Boolean {
        try {
            val  property = this.select(SFilter.eq("id", entity.id!!)).entity()

            val projectId = SPageContext.getHeader("ProjectId")
            val coming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            try {
                /** 日志 */
                val dataCenterLogs = DataCenterLogs()
                dataCenterLogs.id = IdUtils.uuidCreate()
                dataCenterLogs.author = "dataCenter"
                dataCenterLogs.projectId = projectId
                dataCenterLogs.objectType = entity.objectType
                dataCenterLogs.type = "delete"
                dataCenterLogs.account = account
                dataCenterLogs.coming = coming
                dataCenterLogs.objectId = property!!.id
                val hashMap = HashMap<String, Any?>()
                hashMap[entity.objectType!!] = property
                dataCenterLogs.dataSource = hashMap
                logService.insert(dataCenterLogs)
            } catch (e: Exception) {
                e.printStackTrace()
            }

            try {
                /** 清除 */
                if (property!=null&&!property.equipId.isNullOrEmpty()){

                    if (property.equipId!!.startsWith("Eq")){
                        val equipment = EquipmentService.select(SFilter.eq("equipId", property.equipId!!)).entity()
                        if (equipment!=null&&equipment.taskState!=null&&equipment.taskState == -1&&equipment.bimId.isNullOrEmpty() ){
                            val listDel = ArrayList<Equipment>()
                            listDel.add(equipment)
                            EquipmentService.deleteByKeysList(listDel)
                        }
                    }else if (property.equipId!!.startsWith("Ec")){
                        val component = ComponentService.select(SFilter.eq("equipId", property.equipId!!)).entity()
                        if (component?.taskState != null &&component.taskState == -1&&component.bimId.isNullOrEmpty() ){
                            val listDel = ArrayList<Equipment>()
                            listDel.add(component)
                            EquipmentService.deleteByKeysList(listDel)
                        }
                    }
                }
            } catch (e: Exception) {
                e.printStackTrace()
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }

        return super.onDeleteBefore(entity)
    } // Function onDeleteBefore()

} // Object PropertyService
