/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.services.objects

import cn.sagacloud.server.datacenter.utils.IdUtils
import cn.sagacloud.server.datacenter.utils.ShaftNameUtil
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.logs.DataCenterLogs
import com.persagy.server.datacenter.models.entities.objects.ZoneIspace
import com.persagy.server.datacenter.models.requests.DCSQueryRequest
import com.persagy.server.services.base.Service
import com.persagy.service.SPageContext
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SQueryResponse

/**
 * 模型空间信息服务
 *
 * @author 张维新
 */
object SpaceService : Service<ZoneIspace>(SMybatisDao(ZoneIspace::class.java)) {

    /**
     * 创建前的操作
     *
     * @param   space   创建的对象
     */
    override fun onCreateBefore(space: ZoneIspace): Boolean {
        val projectId = SPageContext.getHeader("ProjectId")
        /** 元空间id */
        if (!space.id.isNullOrEmpty()) {
            val isWith = space.id!!.startsWith("Si")
            if (!isWith) {
                space.id = IdUtils.iSpaceIdCreate(projectId!!)
            }
        } else {
            space.id = IdUtils.iSpaceIdCreate(projectId!!)
        }
        space.projectId = projectId

        /** 设备名字 */
        if (space.name.isNullOrEmpty()) {
            space.name = ShaftNameUtil.shaftName("空间-")
        }
        return true
    } // Function onCreateBefore()

    override fun onDeleteBefore(entity: ZoneIspace): Boolean {
        try {
            val zoneIspace = this.select(SFilter.eq("id", entity.id!!)).entity()

            val projectId = SPageContext.getHeader("ProjectId")
            val coming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            /** 日志 */
            val dataCenterLogs = DataCenterLogs()
            dataCenterLogs.id = IdUtils.uuidCreate()
            dataCenterLogs.author = "dataCenter"
            dataCenterLogs.projectId = projectId
            dataCenterLogs.objectType = entity.objectType
            dataCenterLogs.type = "delete"
            dataCenterLogs.coming = coming
            dataCenterLogs.account = account
            dataCenterLogs.objectId = zoneIspace!!.id
            val hashMap = HashMap<String, Any?>()
            hashMap[entity.objectType!!] = zoneIspace
            dataCenterLogs.dataSource = hashMap
            logService.insert(dataCenterLogs)
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return super.onDeleteBefore(entity)
    }


    /**
     * 查询元空间
     */
    fun queryIspace(request: DCSQueryRequest): SQueryResponse<ZoneIspace> {
        return try {
            if (!request.floorId.isNullOrEmpty()) {

                val projectId = SPageContext.getHeader("ProjectId")

                val queryBuilder = select(request.filters)
                val entity = FloorService.select(SFilter.eq("id", request.floorId!!)).entity()
                if (entity!=null&&entity.modelId.isNullOrEmpty()){
                    queryBuilder.filter(SFilter.eq("floorId", request.floorId!!))
                }else{
                    queryBuilder.tableName = "f_ispace('$projectId','${request.floorId}')"
                }
                if (null != request.projection) {
                    queryBuilder.projection(request.projection!!)
                }
                if (null != request.orders) {
                    queryBuilder.order(request.orders!!)
                }

                val sPageQueryInfo = queryBuilder.pageQuery(request.pageNumber, request.pageSize)

                val sQueryResponse = SQueryResponse(sPageQueryInfo)
                sQueryResponse.message = request.floorId!!
                sQueryResponse

            } else {
                pageQuery(request, arrayListOf(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString())))
            }
        } catch (e: Exception) {
            e.printStackTrace()
            SQueryResponse(SResponseType.failure, e.message!!)
        }
    } //


} // Object SpaceService