package com.persagy.server.services.rel

import com.persagy.server.datacenter.models.entities.rel.RShInSyList
import com.persagy.server.datacenter.models.entities.rel.RSyInSh
import com.persagy.server.datacenter.models.entities.rel.RSyInShList
import com.persagy.server.services.base.RService
import com.persagy.base.extensions.toJson
import com.persagy.mybatis.SMybatisDao
import com.persagy.service.SPageContext
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import org.json.JSONObject

/**
 * 系统所在竖井关系服务
 *
 * @author 付国宝
 */
object RSyInShService: RService<RSyInSh>(SMybatisDao(RSyInSh::class.java)) {

    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInSh    系统所在竖井关系对象
     */
    fun create(rSyInSh: RSyInSh): SCreateResponse<RSyInSh> {
        return try {
            val projectId = SPageContext.getHeader("ProjectId")
            rSyInSh.projectId = projectId
            val isInsert = insert(rSyInSh)
            if (isInsert){
                val jsonObject = JSONObject()
                jsonObject.put("type", "11")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rSyInSh.shaftId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",rSyInSh.sysId)

                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenterrel", RelationNotice(projectId!!, "Sy2Sh", "11", IdUtils.uuidCreate(),  rSyInSh.sysId!!, rSyInSh.shaftId!!),false)
                SCreateResponse(SResponseType.success)
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e: Exception){
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function create()

    /**
     * 根据对象删除
     *
     * @param    rSyInSh    关系对象实例
     * @return
     */
    fun deletes(rSyInSh: RSyInSh): SBaseResponse {
        return try {
            val projectId = SPageContext.getHeader("ProjectId")
            val isDelete = delete(rSyInSh)
            /** 删除成功 */
            if (isDelete) {
                val jsonObject = JSONObject()
                jsonObject.put("type", "12")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rSyInSh.shaftId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",rSyInSh.sysId)
                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenterrel", RelationNotice(projectId!!, "Sy2Sh", "12", IdUtils.uuidCreate(),  rSyInSh.sysId!!, rSyInSh.shaftId!!),false)
                val sBaseResponse = SBaseResponse(SResponseType.success)
                sBaseResponse.message = rSyInSh.toJson()
                sBaseResponse
            } else {
                SBaseResponse(SResponseType.failure)
            }
        }catch (e: Exception){
            e.printStackTrace()
            return SBaseResponse(SResponseType.failure, e.message!!)
        }
    } // Function deletes()

    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInShList    系统和竖井关系的对象列表
     */
    fun createSy(rSyInShList: RSyInShList): SCreateResponse<RSyInSh>{
        return try {
            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
            delete("sysID = '${rSyInShList.sysId}'")
            val projectId = SPageContext.getHeader("ProjectId")
            for (shaftId in rSyInShList.shaftIdList!!){
                val rSyInSh = RSyInSh()
                rSyInSh.sysId = rSyInShList.sysId
                rSyInSh.shaftId = shaftId
                rSyInSh.projectId = projectId
                val replace = replace(rSyInSh)
                if (replace){
                    successList.add(rSyInSh)
                }else{
                    failureList.add(rSyInSh)
                }
            }
            if (successList.size>0){
                val jsonObject = JSONObject()
                jsonObject.put("type", "13")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rSyInShList.sysId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",successList.toJson())
                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenterrel", RelationNotice(projectId!!, "Sy2Sh", "13", IdUtils.uuidCreate(),  rSyInShList.sysId!!,
//                        null),false)
                val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                if (failureList.size>0){
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                }
                sCreateResponse
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e: Exception) {
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createSy()

    /**
    * 创建所在竖井的系统关系
    *
    * @param    rShInSyList    系统和竖井关系的对象列表
    */
    fun createsSh(rShInSyList: RShInSyList): SCreateResponse<RSyInSh>{
        return try {
            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
            delete("shaftID = '${rShInSyList.shaftId}'")
            val projectId = SPageContext.getHeader("ProjectId")
            for (sysId in rShInSyList.sysIdList!!){
                val rSyInSh = RSyInSh()
                rSyInSh.shaftId = rShInSyList.shaftId
                rSyInSh.sysId = sysId
                rSyInSh.projectId = projectId
                val replace = replace(rSyInSh)
                if (replace){
                    successList.add(rSyInSh)
                }else{
                    failureList.add(rSyInSh)
                }
            }
            if (successList.size>0){
                val jsonObject = JSONObject()
                jsonObject.put("type", "13")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rShInSyList.shaftId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",successList.toJson())
                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenterrel", RelationNotice(projectId!!, "Sy2Sh", "13", IdUtils.uuidCreate(),  rShInSyList.shaftId!!,
//                        null),false)

                if (failureList.size>0){
                    val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                    sCreateResponse
                }else{
                    val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                    sCreateResponse
                }
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e:Exception){
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createsSh()

    /**
     * 创建所在竖井的系统关系
     *
     * @param    rShInSyList    系统和竖井关系的对象列表
     */
    fun createsShSys(rShInSyList: RShInSyList): SCreateResponse<RSyInSh>{
        return try {
            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
//            delete("shaftID = '${rShInSyList.shaftId}'")
            val projectId = SPageContext.getHeader("ProjectId")
            for (sysId in rShInSyList.sysIdList!!){
                val rSyInSh = RSyInSh()
                rSyInSh.shaftId = rShInSyList.shaftId
                rSyInSh.sysId = sysId
                rSyInSh.projectId = projectId
                val replace = replace(rSyInSh)
                if (replace){
                    successList.add(rSyInSh)
                }else{
                    failureList.add(rSyInSh)
                }
            }
            if (successList.size>0){
                val jsonObject = JSONObject()
                jsonObject.put("type", "14")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rShInSyList.shaftId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",successList.toJson())
                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenterrel", RelationNotice(projectId!!, "Sy2Sh", "14", IdUtils.uuidCreate(),  rShInSyList.shaftId!!,
//                        null),false)
                if (failureList.size>0){
                    val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                    sCreateResponse
                }else{
                    val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                    sCreateResponse
                }
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e:Exception){
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createsSh()

    /**
     * 创建系统所在竖井关系
     *
     * @param    rSyInShList    系统和竖井关系的对象列表
     */
    fun createSyShs(rSyInShList: RSyInShList): SCreateResponse<RSyInSh>{
        return try {
            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
            val projectId = SPageContext.getHeader("ProjectId")
            for (shaftId in rSyInShList.shaftIdList!!){
                val rSyInSh = RSyInSh()
                rSyInSh.sysId = rSyInShList.sysId
                rSyInSh.shaftId = shaftId
                rSyInSh.projectId = projectId
                val replace = replace(rSyInSh)
                if (replace){
                    successList.add(rSyInSh)
                }else{
                    failureList.add(rSyInSh)
                }
            }
            if (successList.size>0){
                val jsonObject = JSONObject()
                jsonObject.put("type", "14")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", rSyInShList.sysId)
                jsonObject.put("obj_type", "Sy2Sh")
                jsonObject.put("linkId",successList.toJson())
                /** 发送消息 */
                messageHandler.sendMessage(jsonObject.toString())

                val sCreateResponse = SCreateResponse<RSyInSh>(SResponseType.success)
                if (failureList.size>0){
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                }
                sCreateResponse
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e: Exception) {
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createSyShs()

    /**
     * 创建关系
     */
    override fun onCreateSuccess(entityList: ArrayList<RSyInSh>) {
        super.onCreateSuccess(entityList)
        val projectId = SPageContext.getHeader("ProjectId")
        for (rSyInSh in entityList){
            val jsonObject = JSONObject()
            jsonObject.put("type", "11")
            jsonObject.put("projectId", projectId)
            jsonObject.put("id", rSyInSh.shaftId)
            jsonObject.put("obj_type", "Sy2Sh")
            jsonObject.put("linkId",rSyInSh.sysId)

            /** 发送消息 */
            messageHandler.sendMessage(jsonObject.toString())
        }

    } // Function onCreateSuccess()

    /**
     * 删除关系
     */
    override fun onDeleteSuccess(entityList: ArrayList<RSyInSh>) {
        super.onDeleteSuccess(entityList)
        val projectId = SPageContext.getHeader("ProjectId")
        for (rSyInSh in entityList){
            val jsonObject = JSONObject()
            jsonObject.put("type", "12")
            jsonObject.put("projectId", projectId)
            jsonObject.put("id", rSyInSh.shaftId)
            jsonObject.put("obj_type", "Sy2Sh")
            jsonObject.put("linkId",rSyInSh.sysId)
            /** 发送消息 */
            messageHandler.sendMessage(jsonObject.toString())
        }
    } // Function onDeleteSuccess()

} // Object RSyInShService