package com.persagy.server.labsl.controller

import com.persagy.server.labsl.models.entities.Graph
import com.persagy.server.labsl.services.GraphService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 图形
 *
 * @author wx
 */
@Api(tags = ["001、图实例"])
@RestController
@RequestMapping("/service/graph")
class GraphController {

    /**
     * 创建图
     *
     * @param   request     待图对象列表
     * @return  创建完成图对象列表
     */
    @ApiOperation(value="创建图", notes="")
    @PostMapping("/create")
    fun create(@RequestBody request: SCreateRequest<Graph>): SCreateResponse<Graph> {
        return GraphService.createList(request)
    } // Function create()

    /**
     * 提交图形
     *
     * @param   graph   待图对象
     * @return  图对象列表
     */
    @ApiOperation(value="提交图形", notes="")
    @PostMapping("/save")
    fun save(@RequestBody graph: Graph): SCreateResponse<Graph> {
        return GraphService.save(graph)
    } // Function save()

    /**
     * 根据id删除图形
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     */
    @ApiOperation(value = "根据id删除图形信息", notes = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 图、移至或移出回收站
     */
    @ApiOperation(value = "图、移至或移出回收站", notes = "IsRelease true 移至回收站 false 移出回收站，")
    @PostMapping(value = ["/recycle"])
    fun recycle(@RequestBody idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.recycle(idList)
    } // Function recycle()

    /**
     * 更新图形信息
     *
     * @param   request        更新的内容对象
     * @return                  更新的结果
     */
    @ApiOperation(value = "更新图形信息", notes = "")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<Graph>): SBaseResponse {
        return GraphService.updateList(request)
    } // Function update()

    /**
     * 查询图形信息
     *
     * @param   request        查询条件
     * @return                 查询结果
     */
    @ApiOperation(value = "查询图形信息", notes = "")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<Graph> {
        return GraphService.pageQuery(request)
    } // Function query()


} // Class GraphController