package com.persagy.server.labsl.services

import cn.sagacloud.server.datacenter.utils.IdUtils
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.labsl.models.entities.Graph
import com.persagy.service.SObjectService
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import java.util.*
import kotlin.collections.ArrayList

/**
 * 图服务
 *
 * @author wx
 */
object GraphService : SObjectService<Graph>(SMybatisDao(Graph::class.java)) {

    /**
     * 创建之前回调
     */
    override fun onCreateBefore(entity: Graph): Boolean {
        // id 赋值
        entity.id = IdUtils.uuidCreate()
        return super.onCreateBefore(entity)
    } // Fun onCreateBefore()

    /**
     * 创建图
     * @param   graph   图对象
     */
    fun save(graph: Graph): SCreateResponse<Graph> {
        //开启事务
        openTransaction()
        if (graph.id.isNullOrEmpty()) {
            // id赋值
            graph.id = UUID.randomUUID().toString().replace("-", "")
        }
        val insertGraph = insert(graph)
        if (!insertGraph){
            // 事务回滚
            backTransaction()
        }
        if (graph.elements != null) {
            val nodesList = graph.elements!!.nodes
            if (!nodesList.isNullOrEmpty()) {
                for (nodes in nodesList) {
                    nodes.graphId = graph.id
                    if (nodes.id.isNullOrEmpty()) {
                        // id赋值
                        nodes.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    val insertNode = NodeService.insert(nodes)
                    if (!insertNode) {
                        // 事务回滚
                        backTransaction()
                        break
                    }
                    val anchorList = nodes.anchorList
                    if (!anchorList.isNullOrEmpty()) {
                        for (anchor in anchorList) {
                            anchor.graphId = graph.id
                            anchor.nodeId = nodes.id
                            if (anchor.id.isNullOrEmpty()) {
                                // id赋值
                                anchor.id = UUID.randomUUID().toString().replace("-", "")
                            }
                            val insertAnchor = AnchorService.insert(anchor)
                            if (insertAnchor) {
                                // 事务回滚
                                backTransaction()
                                break
                            }
                        }
                    }
                }
            }
            val markersList = graph.elements!!.markers
            if (!markersList.isNullOrEmpty()) {
                for (markers in markersList) {
                    markers.graphId = graph.id
                    if (markers.id.isNullOrEmpty()) {
                        // id赋值
                        markers.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    val insertMarkers = MarkersService.insert(markers)
                    if (!insertMarkers) {
                        // 事务回滚
                        backTransaction()
                        break
                    }
                }
            }
            val relationsList = graph.elements!!.relations
            if (!relationsList.isNullOrEmpty()) {
                for (relations in relationsList) {
                    relations.graphId = graph.id
                    if (relations.id.isNullOrEmpty()) {
                        // id赋值
                        relations.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    val insertRelation = RelationService.insert(relations)
                    if (!insertRelation) {
                        // 事务回滚
                        backTransaction()
                        break
                    }
                }
            }
        }
        // 提交事务
        commitTransaction()
        val sCreateResponse = SCreateResponse<Graph>(SResponseType.success)
        sCreateResponse.entityList = arrayListOf(graph)
        return sCreateResponse
    } // Fun save（）

    /**
     * 开启事务
     */
    private fun openTransaction() {

    } // Fun openTransaction()

    /**
     * 回滚事务
     */
    private fun backTransaction() {

    } // Fun backTransaction()

    /**
     * 提交事务
     */
    private fun commitTransaction(){

    } // Fun commitTransaction()


    /**
     * 图、移至回收站 或移出回收站
     */
    fun recycle(idList: ArrayList<Graph>): SBaseResponse {
        val sBaseResponse = SBaseResponse()
        if (!idList.isNullOrEmpty()){
            for (graph in idList){
                val list = ArrayList<String>()
                list.add("IsPub")
                update(graph,list)
            }
            sBaseResponse.result = SResponseType.success
        }else{
            sBaseResponse.result = SResponseType.failure
        }
        return sBaseResponse
    } // Fun recycle()



} // Object GraphService