/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller

import com.persagy.base.extensions.toJson
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.scanbuilding.NoteTemplate
import com.persagy.service.SObjectService
import com.persagy.service.models.requests.SCountRequest
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCountResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.*

/**
 * 二维码标签信息说明接口
 *
 * @author 付国宝
 */
@Api(tags = ["011、二维码标签信息说明接口"])
@RestController
@RequestMapping("/note-template")
open class NoteTemplateController {
    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(NoteTemplateController::class.java)
    } // Companion object

    private var baseService = SObjectService(SMybatisDao(NoteTemplate::class.java))

    /**
     * 批量创建二维码标签信息说明
     *
     * @param   request      二维码标签信息说明对象列表
     * @return                  创建结果信息
     */
    @ApiOperation(value = "创建二维码标签信息说明", notes = "")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<NoteTemplate>): SCreateResponse<NoteTemplate> {
        logger.debug("noteTemplate =${request.toJson()}")
        return baseService.createList(request)
    } // Function create()

    /**
     * 根据id删除二维码标签信息说明
     *
     * @param   entityList  二维码标签信息说明数组
     * @return              删除的结果信息
     */
    @ApiOperation(value = "根据id删除二维码标签信息说明", notes = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody entityList: ArrayList<NoteTemplate>): SBaseResponse {
        return baseService.deleteByKeysList(entityList)
    } // Function delete()

    /**
     * 更新二维码标签信息说明
     *
     * @param   request     更新的内容对象
     * @return              更新的结果
     */
    @ApiOperation(value = "更新二维码标签信息说明", notes = "")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<NoteTemplate>): SBaseResponse {
        return baseService.updateList(request)
    } // Function update()

    /**
     * 查询二维码标签信息说明
     *
     * @param   request     查询信息条件
     * @return              查询结果
     */
    @ApiOperation(value = "查询二维码标签信息说明", notes = "")
    @GetMapping(value = ["/query"])
    fun query(): SQueryResponse<NoteTemplate> {
       val  request= SQueryRequest()
        return baseService.pageQuery(request)
    } // Function query()

    /**
     * 根据条件查询统计数量
     */
    @ApiOperation(value = "根据条件查询统计数量", notes = "")
    @PostMapping(value = ["/count"])
    fun count(@RequestBody request: SCountRequest): SCountResponse {
        return baseService.count(request)
    } // Function count()

} // Class NoteTemplateController