/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller

import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.entities.User
import com.persagy.server.entities.request.ProjectChangeRequest
import com.persagy.server.entities.request.UserLoginRequest
import com.persagy.server.entities.request.VerifyCodeRequest
import com.persagy.server.entities.response.BaseResponse
import com.persagy.server.entities.response.UserLoginResponse
import com.persagy.server.entities.response.UserResponse
import com.persagy.server.services.UserService
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCountRequest
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCountResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.*

/**
 * 用户信息接口
 *
 * @author 付国宝
 */
@Api(tags = ["008、用户信息接口"])
@RestController
@RequestMapping("/service/user")
open class UserController {
    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(UserController::class.java)
    } // Companion object

    private var baseService = SObjectService(SMybatisDao(User::class.java))



    /**
     * 扫楼用户登录
     *
     * @param   body        用户登录请求
     */
    @ApiOperation(value="扫楼用户登录", notes="")
    @PostMapping("login")
    @ResponseBody
    open fun login(@Validated @RequestBody body: UserLoginRequest): UserLoginResponse {
        //userLogService.write(BaseRequest.Comming.app, null, null, "用户登录", null, body.toLog())
        return UserService.login(body.phone!!, body.code!!)
    } // Function login()

    /**
     * 扫楼用户获得验证码
     *
     * @param   body        验证码请求
     */
    @ApiOperation(value="扫楼用户获得验证码", notes="")
    @PostMapping("verify_code")
    @ResponseBody
    open fun getVerifyCode(@Validated @RequestBody body: VerifyCodeRequest): BaseResponse {
        //userLogService.write(BaseRequest.Comming.app, null, null, "获得验证码", null, body.toLog())
        val userList = UserService.queryByPhone(body.phone!!)
        if (userList.isEmpty()) {
            return BaseResponse(BaseResponse.ResultCode.failure, "手机号‘${body.phone!!}’未注册！")
        }
        return UserService.getVerifyCode(body.phone!!)
    } // Function getVerifyCode()


    /**
     * 批量创建用户信息
     *
     * @param   request         用户信息对象列表
     * @return                  创建结果信息
     */
    @ApiOperation(value = "创建用户信息", notes = "")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<User>): SCreateResponse<User> {
        logger.debug("user =${request.toJson()}")
        return UserService.createList(request)
    } // Function create()


    /**
     * 根据id删除用户信息
     *
     * @param   entityList  用户信息数组
     * @return              删除的结果信息
     */
    @ApiOperation(value = "根据id删除用户信息", notes = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody entityList: ArrayList<User>): SBaseResponse {
        return UserService.deleteByKeysList(entityList)
    } // Function delete()

    /**
     * 更新用户信息
     *
     * @param   request     更新的内容对象
     * @return              更新的结果
     */
    @ApiOperation(value = "更新用户信息", notes = "")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<User>): SBaseResponse {
        return UserService.updateList(request)
    } // Function update()

    /**
     * 扫楼用户切换项目
     */
    @ApiOperation(value="扫楼用户切换项目", notes="")
    @PostMapping("change_project")
    @ResponseBody
    open fun switchProject(@Validated @RequestBody body: ProjectChangeRequest): BaseResponse {
        try {
//            val user: cn.sagacloud.server.scanbuilding.entities.User? = userService.changeProject(body.projId!!, body.phone!!) ?: return BaseResponse()
            val user = UserService.select(SFilter.eq("projId", body.projId!!), SFilter.eq("phone", body.phone!!)).entity()?: return BaseResponse()
//            userLogService.write(body.comming!!, body.projId, user!!.userId,"用户登录", null, body.toLog())
            return UserResponse(user)
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return BaseResponse()
    } // Function switchProject()


    /**
     * 查询用户信息
     *
     * @param   request     查询信息条件
     * @return              查询结果
     */
    @ApiOperation(value = "查询用户信息", notes = "")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<User> {
        val projectId = SPageContext.getHeader("ProjectId")
        return UserService.pageQuery(request, arrayListOf(SFilter.eq("projId",projectId!!)))
    } // Function query()

    /**
     * 根据条件查询统计数量
     */
    @ApiOperation(value = "根据条件查询统计数量", notes = "")
    @PostMapping(value = ["/count"])
    fun count(@RequestBody request: SCountRequest): SCountResponse {
        return UserService.count(request)
    } // Function count()


} // Class UserController