/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller.task

import com.alibaba.fastjson.JSON
import com.alibaba.fastjson.JSONObject
import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.server.datacenter.models.entities.assistant.TaskPic
import com.persagy.server.datacenter.models.entities.task.*
import com.persagy.server.services.EquipmentService
import com.persagy.server.services.task.EquipScanTaskQueryService
import com.persagy.server.services.task.EquipScanTaskService
import com.persagy.server.services.task.ScanTaskBaseService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController


/**
 * 设备台账任务接口
 *
 * @author  邓婷婷
 */
@Api(tags = ["001、任务-设备台账任务接口"])
@RestController
@RequestMapping("/task/equip")
open class EquipScanTaskController {

    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(EquipScanTaskController::class.java)
    } // Companion object

    /**
     * 根据条件查询设备台账任务
     *
     * @author 邓婷婷
     *
     * {
            "Cascade": [
                {
                "Name": "project"
                }
            ],
            "Filters": "TaskState = 1 || TaskState = -1",
            "PageNumber": 1,
            "PageSize": 50
        }
     */
    @ApiOperation(value = "查询设备台账任务", notes = "级联查询对象：项目（project）、建筑（building）、楼层（floor）、方案（scanScheme）、部件（component）、设备分类（equipCategory）;" +
            "查询条件：任务类型（TaskSource--int）、任务执行情况（TaskState--int）、所属建筑（BuildingId）、所属楼层（FloorId）、设备类型（Category）")
    @PostMapping(value = ["/page-query"])
    fun pageQuery(@RequestBody request: SQueryRequest): SQueryResponse<EquipScanTaskQuery> {
        logger.debug("EquipScanTaskQuery =${request.toJson()}")
//        val equipScanTaskQueryService = SObjectService(SMybatisDao(EquipScanTaskQuery::class.java))
//        val withFilterList = ArrayList<SFilter>()
//        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
//        withFilterList.add(SFilter.lt(SLength("category"), 6))
        return EquipScanTaskQueryService.pageQuerys(request)
    } // Function pageQuery()

    @ApiOperation(value = "查询设备台账任务,包含部件", notes = "级联查询对象：项目（project）、建筑（building）、楼层（floor）、方案（scanScheme）、部件（component）、设备分类（equipCategory）;" +
            "查询条件：任务类型（TaskSource--int）、任务执行情况（TaskState--int）、所属建筑（BuildingId）、所属楼层（FloorId）、设备类型（Category）")
    @PostMapping(value = ["/page-query-com"])
    fun pageQueryCom(@RequestBody request: SQueryRequest): SQueryResponse<EquipScanTaskQuery> {
        logger.debug("EquipScanTaskQuery =${request.toJson()}")
//        val equipScanTaskQueryService = SObjectService(SMybatisDao(EquipScanTaskQuery::class.java))
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
//        withFilterList.add(SFilter.lt(SLength("category"), 6))
        return EquipScanTaskQueryService.pageQuery(request, withFilterList)
    }

    /**
     * 创建设备台账任务
     *
     * @param   request        设备台账任务对象列表
     * @return                      创建结果信息
     * @author  邓婷婷
     *
     * {
            "Content": [
                {
                "EquipId": "Eq11022900026d3f63a95c1511e9a7ded32044b9b08d",
                "EquipName": "太阳能电池板-EQ3A3"
                }
            ]
        }
     */
    @ApiOperation(value = "创建设备台账", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；当任务为未找到任务时重新生成任务，需要将TaskState=-1带入;")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<EquipScanTask>): SCreateResponse<EquipScanTask> {
        logger.debug("equip =${request.toJson()}")
        return EquipScanTaskService.createList(EquipScanTaskService.createBefore(request))
    } // Function create()

    /**
     * 更新设备台账
     *
     * @param   request      设备台账对象列表
     * @return              结果信息
     * @author  邓婷婷
     *
     * {
    "Content": [
    {
    "TaskId": "1",
    "TaskState":1,
    }
    ]
    }
     *
     */
    @ApiOperation(value = "更新设备台账任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<EquipScanTask>): SBaseResponse {
        return EquipScanTaskService.updateList(request)
    } // Function update()

    /**
     * 根据id删除设备台账
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     *
     * @author  邓婷婷
     *
     * [
            {
            "TaskId": "3"
            }
        ]
     */
    @ApiOperation(value = "根据id删除设备台账", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<EquipScanTask>): SBaseResponse {
        return EquipScanTaskService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 查询设备分类
     */
    @ApiOperation(value = "查询设备分类",notes = "")
    @PostMapping(value = ["/equip-category-query"])
    fun equipCategoryQuery(): SQueryResponse<EquipCategoryDic>{
        return ScanTaskBaseService.equipCategoryQuery("equip");
    } // Function EquipCategoryQuery()

    /**
     * 查询建筑和楼层
     */
    @ApiOperation(value = "查询建筑和楼层",notes = "")
    @PostMapping(value = ["/equip-building-query"])
    fun buildingQuery(): SQueryResponse<BuildingDic>{
        return ScanTaskBaseService.buildingQuery("equip");
    } // Function BuildingQuery()

    /**
     * 查询设备任务下的部件类型及数量
     */
    @ApiOperation(value = "查询设备任务下的部件类型及数量",notes = "TaskId、EquipId 必填  ")
    @PostMapping(value = ["/category-count"])
    fun categoryCount(@RequestBody equipScanTask: EquipScanTask): SQueryResponse<CategoryStatistics>{
        return ScanTaskBaseService.categoryCounts(equipScanTask)
    } // Fun

//    /**
//     * 获取建筑楼层
//     */
//    @ApiOperation(value = "查询设备任务的建筑楼层",notes = "TaskId、EquipId 必填  ")
//    @PostMapping(value = ["/category-count"])
//    fun taskEquipBuildingFloor(){
//
//    } // Fun
    /**
     * 任务图片和安装位置同步到设备
     */
    @ApiOperation(value = "任务图片和安装位置同步到设备",notes = "TaskId、EquipId 必填  ")
    @PostMapping(value = ["/equipinfo"])
    fun equipInfo(){
        val projectId = SPageContext.getHeader("ProjectId").toString()
        val equipScanTaskList = EquipScanTaskQueryService.select(SFilter.eq("projectId", projectId), SFilter.eq("taskState", 0),SFilter.not(SFilter.isNull("manufacturer"))).exec()
        if (equipScanTaskList.size>0){
            for (equipScanTask in  equipScanTaskList){
                val equipment = EquipmentService.select(SFilter.eq("id", equipScanTask.equipId!!)).entity()
                if (equipment!=null){
                    if (!equipScanTask.taskPicList.isNullOrEmpty()&&equipScanTask.taskPicList!!.size>0){
                        val photoDoc = HashMap<String,Any?>()
                        if (equipment.ledgerParam.isNullOrEmpty()) {
                            equipment.ledgerParam = HashMap<String,Any?>()

                            val map = HashMap<String,Any?>()
                            val picList = ArrayList<TaskPic>()
                            for (taskPic in equipScanTask.taskPicList!!){
                                if (!taskPic.name.isNullOrEmpty()&&taskPic.name == "铭牌照片"){
                                    val taskPic1 = TaskPic()
                                    taskPic1.key = taskPic.key
                                    taskPic1.createTime = taskPic.createTime
                                    taskPic1.name = taskPic.name
                                    taskPic1.type = taskPic.type
                                    val  nameplateList = ArrayList<TaskPic>()
                                    nameplateList.add(taskPic1)
                                    photoDoc["Nameplate"] = nameplateList
                                }else{
                                    picList.add(taskPic)
                                }
                            }
                            if (!equipScanTask.installLocation.isNullOrEmpty()){
                                val installLocationMap = HashMap<String,String?>()
                                installLocationMap["InstallLocation"] = equipScanTask.installLocation
                                val siteinstallMap = HashMap<String,Any?>()
                                siteinstallMap["Siteinstall"] =installLocationMap
                                map["Siteinstall"] = installLocationMap
                            }
                            photoDoc["Pic"] = picList
                            map["PhotoDoc"] = photoDoc
                            equipment.ledgerParam = map
                            val list = ArrayList<String>()
                            list.add("LedgerParam")
                            EquipmentService.update(equipment,list)
                        }else{

                            val map = HashMap<String,Any?>()
                            val picList = ArrayList<TaskPic>()
                            for (taskPic in equipScanTask.taskPicList!!){
                                if (!taskPic.name.isNullOrEmpty()&&taskPic.name == "铭牌照片"){
                                    val taskPic1 = TaskPic()
                                    taskPic1.key = taskPic.key
                                    taskPic1.createTime = taskPic.createTime
                                    taskPic1.name = taskPic.name
                                    taskPic1.type = taskPic.type
                                    val  nameplateList = ArrayList<TaskPic>()
                                    nameplateList.add(taskPic1)
                                    photoDoc["Nameplate"] = nameplateList
                                }else{
                                    picList.add(taskPic)
                                }
                            }
//                            if (!equipScanTask.installLocation.isNullOrEmpty()){
//                                val installLocationMap = HashMap<String,String?>()
//                                installLocationMap["InstallLocation"] = equipScanTask.installLocation
//                                val siteinstallMap = HashMap<String,Any?>()
//                                siteinstallMap["Siteinstall"] =installLocationMap
//                                map["Siteinstall"] = installLocationMap
//                            }

                            val containsKey = equipment.ledgerParam!!.containsKey("Siteinstall")
                            if (containsKey){
                                val siteinstallJson = JSONObject.parseObject(JSON.toJSONString(equipment.ledgerParam!!["Siteinstall"]))
                                siteinstallJson.put("InstallLocation",equipScanTask.installLocation)
                                equipment.ledgerParam!!["Siteinstall"] = siteinstallJson
                            }
                            photoDoc["Pic"] = picList
                            equipment.ledgerParam!!["PhotoDoc"] = photoDoc
                            val list = ArrayList<String>()
                            list.add("LedgerParam")
                            EquipmentService.update(equipment,list)

                        }
                    }
                }
            }
        }
    } //



} // Class EquipScanTaskController