/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller.task

import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.server.datacenter.models.entities.task.BuildingDic
import com.persagy.server.datacenter.models.entities.task.EquipCategoryDic
import com.persagy.server.datacenter.models.entities.task.PropertyScanTask
import com.persagy.server.services.task.PropertyScanTaskService
import com.persagy.server.services.task.ScanTaskBaseService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCountRequest
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCountResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController


/**
 * 资产台账任务接口
 *
 * @author  邓婷婷
 */
@Api(tags = ["003、任务-资产台账任务接口"])
@RestController
@RequestMapping("/task/property")
open class PropertyScanTaskController {

    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(PropertyScanTaskController::class.java)
    } // Companion object

    /**
     * 根据条件查询资产台账任务
     *
     * @author 邓婷婷
     */
    @ApiOperation(value = "查询资产台账任务", notes = "级联查询对象：项目（project）、建筑（building）、楼层（floor）、方案（scanScheme）、设备族（equipFamily）;" +
            "查询条件：任务类型（TaskSource--int）、任务执行情况（TaskState--int）、所属建筑（BuildingId）、所属楼层（FloorId）、设备类型（Category）")
    @PostMapping(value = ["/page-query"])
    fun pageQuery(@RequestBody request: SQueryRequest): SQueryResponse<PropertyScanTask> {
        logger.debug("propertyScanTaskQuery =${request.toJson()}")
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
        return PropertyScanTaskService.pageQuery(request,withFilterList);
    } // Function pageQuery()

    /**
     * 创建资产台账任务
     *
     * @param   request        资产台账任务对象列表
     * @return                      创建结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "创建资产台账任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；当任务为未找到任务时重新生成任务，需要将TaskState=-1带入;")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<PropertyScanTask>): SCreateResponse<PropertyScanTask> {
        logger.debug("equip =${request.toJson()}")
        return PropertyScanTaskService.createList(PropertyScanTaskService.createBefore(request))
    } // Function create()

    /**
     * 更新资产台账任务
     *
     * @param   request      资产台账任务对象列表
     * @return              结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "更新资产台账任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<PropertyScanTask>): SBaseResponse {
        return PropertyScanTaskService.updateList(request)
    } // Function update()

    /**
     * 根据id删除资产台账任务
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     *
     * @author  邓婷婷
     */
    @ApiOperation(value = "根据id删除资产台账任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<PropertyScanTask>): SBaseResponse {
        return PropertyScanTaskService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 统计数量
     */
    @ApiOperation(value = "统计数量", notes = "查询未完成撕码任务TaskState=1&&TaskType='3' ，未完成换码任务TaskState=1&&TaskType='2'")
    @PostMapping(value = ["/count"])
    fun count(@RequestBody request: SCountRequest): SCountResponse {
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
        return PropertyScanTaskService.count(request,withFilterList)
    } // Function count()

    /**
     * 查询设备族
     */
    @ApiOperation(value = "查询设备族",notes = "")
    @PostMapping(value = ["/property-category-query"])
    fun propertyCategoryQuery(): SQueryResponse<EquipCategoryDic>{
        return ScanTaskBaseService.equipCategoryQuery("property");
    } // Function PropertyCategoryQuery()

    /**
     * 查询建筑和楼层
     */
    @ApiOperation(value = "查询建筑和楼层",notes = "")
    @PostMapping(value = ["/property-building-query"])
    fun buildingQuery(): SQueryResponse<BuildingDic>{
        return ScanTaskBaseService.buildingQuery("property");
    } // Function BuildingQuery()

} // Class PropertyScanTaskController