/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller.task


import com.persagy.base.extensions.toJson
import com.persagy.server.datacenter.models.entities.task.ScanScheme
import com.persagy.server.services.task.ScanSchemeService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController


/**
 * 任务方案接口
 *
 * @author  邓婷婷
 */
@Api(tags = ["005、任务-方案接口"])
@RestController
@RequestMapping("task/scheme")
open class ScanSchemeController {

    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(ScanSchemeController::class.java)
    } // Companion object

    /**
     * 根据条件查询任务方案
     *
     * @author 邓婷婷
     */
    @ApiOperation(value = "查询任务方案", notes = "级联查询对象：信息点（scanSchemeInfoList）")
    @PostMapping(value = ["/page-query"])
    fun pageQuery(@RequestBody request: SQueryRequest): SQueryResponse<ScanScheme> {
        logger.debug("scanSchemeQuery =${request.toJson()}")
        return ScanSchemeService.pageQuery(request);
    } // Function pageQuery()

    /**
     * 创建任务方案
     *
     * @param   request        任务方案对象列表
     * @return                      创建结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "创建任务方案", notes = "")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<ScanScheme>): SCreateResponse<ScanScheme> {
        logger.debug("scanScheme =${request.toJson()}")
        return ScanSchemeService.createList(request)
    } // Function create()

    /**
     * 更新任务方案
     *
     * @param   idList      任务方案对象列表
     * @return              结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "更新任务方案", notes = "")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<ScanScheme>): SBaseResponse {
        return ScanSchemeService.updateList(request)
    } // Function update()


    /**
     * 根据id删除任务方案
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     *
     * @author  邓婷婷
     */
    @ApiOperation(value = "根据id删除任务方案", notes = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<ScanScheme>): SBaseResponse {
        return ScanSchemeService.deleteByKeysList(idList)
    } // Function delete()

} // Class ScanSchemeController