package com.persagy.server.services.base

import com.persagy.database.SAbstractDao
import com.persagy.database.extensions.keyValue
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.base.BaseInfo
import com.persagy.server.datacenter.models.entities.logs.DataCenterLogs
import com.persagy.server.services.task.SchemeService
import com.persagy.server.util.IdUtils
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.utils.SSpringContextUtil
import org.json.JSONArray
import org.json.JSONObject
import org.slf4j.LoggerFactory


/**
 * 服务基类
 *
 * @author 张维新
 */
open class Service<ENTITY : BaseInfo>(daoClass: SAbstractDao<ENTITY>) : SObjectService<ENTITY>(daoClass) {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(Service::class.java)

//        /** MQ消息对象 */
//        val messageHandler by lazy {
//            SSpringContextUtil.getBean(MessageHandler::class.java) as MessageHandler
//        }

        /** 自定义sql */
         val schemeService by lazy {
            SSpringContextUtil.getBean(SchemeService::class.java) as SchemeService
        }

        /** kafka消息对象 */
//        val kafkaService by lazy {
//            SSpringContextUtil.getBean(KafkaService::class.java) as KafkaService
//        }

    } // Companion object
    /** 日志 */
    var logService = SObjectService(SMybatisDao(DataCenterLogs::class.java))

    /**
     * 创建成功回调函数
     *
     * @param   entityList          创建成功对象
     */
    override fun onCreateSuccess(entityList: ArrayList<ENTITY>) {

        entityList.forEach {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")

            try {
                val jsonObject = JSONObject()
                jsonObject.put("type", "1")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", it.keyValue("id"))
                jsonObject.put("obj_type", it.objectType)
                /** 发送消息 */
//                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenter", ObjectNotice(projectId!!, it.objectType!!, "create",IdUtils.uuidCreate(), hashSetOf(it.keyValue("id").toString())),false)

            } catch (e: Exception) {
                e.printStackTrace()
            }
            try {
                /** 日志 */
                val dataCenterLogs = DataCenterLogs()
                dataCenterLogs.id = IdUtils.uuidCreate()
                dataCenterLogs.author = "dataCenter"
                dataCenterLogs.projectId = projectId
                dataCenterLogs.objectType = it.objectType
                dataCenterLogs.type = "create"
                dataCenterLogs.coming = comming
                dataCenterLogs.account = account
                dataCenterLogs.objectId = it.keyValue("id").toString()
                val hashMap = HashMap<String, Any?>()
                hashMap[it.objectType!!] = it
                dataCenterLogs.dataSource = hashMap
                logService.insert(dataCenterLogs)
            } catch (e: Exception) {
                e.printStackTrace()
            }


        }
//        entityList.forEach {
//            if (it.objectType =="Equipment") {
//                logger.debug("设备数据id${it.keyValue("id")}*******************************")
//                logger.debug("资产数据id${it.keyValue("propertyId")}*******************************")
//            }
//        }

        return
    } // Function onCreateSuccess()

    /**
     * 删除成功回调函数
     *
     * @param   entityList      删除成功对象列表
     */
    override fun onDeleteSuccess(entityList: ArrayList<ENTITY>) {
        val projectId = SPageContext.getHeader("ProjectId")
        entityList.forEach {

            try {
                val jsonObject = JSONObject()
                jsonObject.put("type", "2")
                jsonObject.put("projectId", projectId)
                jsonObject.put("id", it.keyValue("id"))
                jsonObject.put("obj_type", it.objectType)
                /** 发送消息 */
//                messageHandler.sendMessage(jsonObject.toString())
//                kafkaService.sendNotice("datacenter", ObjectNotice(projectId!!, it.objectType!!, "delete",IdUtils.uuidCreate(), hashSetOf(it.keyValue("id").toString())),false)
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }
        return
    } // Function onDeleteSuccess()


    override fun onUpdateBefore(entity: ENTITY): Boolean {

        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            /** 日志 */
            val dataCenterLogs = DataCenterLogs()
            dataCenterLogs.id = IdUtils.uuidCreate()
            dataCenterLogs.author = "dataCenter"
            dataCenterLogs.projectId = projectId
            dataCenterLogs.objectType = entity.objectType
            dataCenterLogs.type = "update-before"
            dataCenterLogs.account = account
            dataCenterLogs.coming = comming
            dataCenterLogs.objectId = entity.keyValue("id").toString()
            val hashMap = HashMap<String, Any?>()
            hashMap[entity.objectType!!] = entity
            dataCenterLogs.dataSource = hashMap
            logService.insert(dataCenterLogs)
        } catch (e: Exception) {
            e.printStackTrace()
    }

        return super.onUpdateBefore(entity)
    }

    /**
     * 更新成功能回调函数
     *
     * @param   entityList      更新成功对象列表
     */
    override fun onUpdateSuccess(entityList: ArrayList<ENTITY>) {
        try {
            val projectId = SPageContext.getHeader("ProjectId")
            val comming = SPageContext.getHeader("Coming")
            val account = SPageContext.getHeader("Account")
            val jsonObject = JSONObject()
            jsonObject.put("type", "7")
            jsonObject.put("projectId", projectId)
            jsonObject.put("obj_type", entityList[0].objectType)
            val jsonArray = JSONArray()
            for (entity in entityList) {
                val jsonInfos = JSONObject()
                jsonInfos.put("id", entity.keyValue("id"))
                jsonInfos.put("obj_type", entity.objectType)
                jsonArray.put(jsonInfos)

                try {
                    /** 日志 */
                    val dataCenterLogs = DataCenterLogs()
                    dataCenterLogs.id = IdUtils.uuidCreate()
                    dataCenterLogs.author = "dataCenter"
                    dataCenterLogs.projectId = projectId
                    dataCenterLogs.objectType = entity.objectType
                    dataCenterLogs.type = "update-after"
                    dataCenterLogs.account = account
                    dataCenterLogs.coming = comming
                    dataCenterLogs.objectId = entity.keyValue("id").toString()
                    val hashMap = HashMap<String, Any?>()
                    hashMap[entity.objectType!!] = entity
                    dataCenterLogs.dataSource = hashMap
                    logService.insert(dataCenterLogs)
                } catch (e: Exception) {
                    e.printStackTrace()
                }

                try {
                    /** 发送消息 */
//                    kafkaService.sendNotice("datacenter", ObjectNotice(projectId!!, entity.objectType!!, "update",IdUtils.uuidCreate(), hashSetOf(entity.keyValue("id").toString())),false)
                } catch (e: Exception) {
                    e.toString()
                }

            }
            jsonObject.put("infos", jsonArray)
            logger.debug("修改发送消息$jsonObject")
            /** 发送消息 */
//            messageHandler.sendMessage(jsonObject.toString())
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return
    } // Function onUpdateSuccess()

} // Class Service
